---
title: 가입신청
category: 포트원 이용절차 (온보딩 가이드) > 전자결제 신청 > 가입신청
seo:
  title: 가입신청
  description: >-
    포트원 전자결제 신청을 위한 안내입니다. PG계약의 첫 단계인 ‘가입신청서 제출’을 반드시 포트원 관리자콘솔에서 신청해야 합니다. 지금
    '전자결제신청' 버튼을 눌러 가입신청서 작성을 시작하세요.
  keywords:
    - 이용절차
    - PG 가입신청
    - 전자결제 가입신청
    - PG계약
tags:
  - 공통
  - 가입신청
pgCompanies:
  - 공통
searchTags:
  - 계약절차
  - 가입절차
  - 가입방법
  - 계약방법
  - 신청방법
  - 사업자 정보 등록
  - 추천패키지
  - 비즈니스인증
  - 전자결제신청
---

<Callout content="포트원의 서비스 사용을 위해 PG계약의 첫 단계 ‘가입신청서 제출’은 반드시 포트원 관리자콘솔에서 신청해 주셔야 합니다. 포트원 관리자콘솔 회원가입 및 로그인 후 좌측 상단 전자결제 신청⚡ 버튼을 눌러 가입신청서 작성을 시작 해보세요!" />

### **비즈니스 인증**

#### **전자결제 신청 메뉴 접속**

처음 전자결제 신청 시에는 신규 사업자등록증 업로드 절차로 진행됩니다.



한 번이라도 포트원을 통해 전자결제 신청하신 이력이 있는 경우, 다음과 같은 화면으로 확인하실 수 있습니다.

이미 신청하신 적이 있는 사업자의 경우 2번의 비즈니스 인증 과정이 생략되며 이전에 업로드하신 사업자 정보를 기반으로 바로 접수하실 수 있습니다. (사업자 정보를 변경하여 접수하고자 하시는 경우 채널톡으로 문의하시기 바랍니다)



#### **사업자정보 등록**



#### **담당자정보 등록**



- 사업자등록증 업로드 시 기본적인 사업자 정보는 자동으로 불러와지나 회사 주소(사업장 주소) , 대표자 휴대폰 번호, 대표자 생년월일 은 직접 입력해 주세요.
- 대표자 이메일 주소를 포트원 계정으로 사용하지 않으시는 경우 체크박스 해제 후 원하시는 이메일 주소로 입력해 주세요.
- \[임시저장]을 클릭하시면 등록 진행 중인 정보가 저장됩니다.

#### **서비스정보 등록**



결제대행사를 통해 심사를 받으실 내용 기준으로 적어주시기 바랍니다.

- 상세 판매 품목 : 판매하시는 서비스 유형(업종)을 선택해 주세요. (중복 선택 가능)
- 서비스 형태 선택 : 연동하시는 서비스의 형태를 선택해 주세요. (웹/앱)
- 월 거래액 : 평균 월 거래액 혹은 예상 매출액을 입력 해주세요.
- 서비스 URL 입력: http 혹은 https까지 입력된 서비스 URL을 입력해 주세요.
  - PG사로부터 심사를 받으실 수 있는 URL로 기재 해주세요.
  - PG 계약을 위해 연동하시는 서비스(웹/앱)에 기본 구성 구현은 필수 사항입니다.
  - ‘앱 서비스’의 경우 서비스 형태를 앱 서비스’로 선택하신 후 앱스토어 등록된 경우 스토어 다운로드 URL을, 앱스토어 미등록 시 ‘아직 앱스토어 등록 전이에요 (URL이 없습니다)’에 체크해 주세요.

#### **최종 확인**



입력하신 사업자 정보에 오류가 없는지 마지막으로 체크해 주세요

- 정보 수정이 필요하시면 \[수정하기] 버튼을 클릭해 주세요.
- 담당자 정보 수정이 필요하시면 \[담당자 정보 수정하기] 버튼을 클릭해 주세요.
- \[제출하기] 클릭 시, \[전자결제 신청하기] 팝업이 실행됩니다. PG 사와 계약을 바로 진행하시려면 \[전자결제 신청하기]를 클릭해 주세요.
- 만약 정보 수정이 불가한 경우 우측 하단 채널톡을 통해 문의하시기 바랍니다.

### **전자결제 신청**

#### **결제서비스 신청**



- 워드프레스 지원 가능한 결제대행사 목록 : 워드프레스로 연동하신다면 지원이 가능한 결제대행사가 구분되어 있으니 반드시 확인 후 진행해 주세요.
- 포트원 추천 패키지 : 어떤 결제대행사를 이용하셔야 할지 고민이신 분들을 위해 포트원에서 서비스별 결제대행사를 추천드립니다.
- 전자결제직접 신청 : 원하는 결제대행사가 정해 직접 결제수단과 대행사를 고르실 수 있습니다.
- 결제수단 알아보기 : 일반결제, 정기결제 용어가 어려우시다면 이미지를 보며 서비스를 이해하실 수 있습니다.

#### **포트원 추천패키지**



좌측 이미지는 모든 추천 패키지가 선택되었을 때 예시 화면입니다.

결제대행사와 결제수단을 직접 고르고자 하실 경우 \[전자결제 직접 신청]을 눌러 이동해주세요

- 추천 PG사 : 클릭한 결제수단에 맞게 추천된 PG가 카드 형식으로 노출됩니다.
- 연동방식 : 결제대행사별로 지원가능한 연동방식에 차이가 있으므로 원하는 연동방식을 고려하여 선택해주세요
  - 결제창 방식 : PG사의 결제창을 불러올 수 있습니다.
  - API 방식 : 결제창을 직접 만들 수 있습니다.
- 결정했어요! : 노출되어 있는 결제대행사 카드는 모두 접수 처리되오니 최종 접수 이전에 이용하실 결제대행사를 한 번 더 체크해 주세요

<Callout title="포트원 추천 패키지 자세히 보러 가기↗" />

#### **전자결제 직접 신청**





포트원에서 추천드리는 결제대행사를 이용하실 경우 \[포트원 추천 패키지] 을 눌러주세요

- 결제방식 : 이용하실 결제방식별 지원 가능한 결제대행사를 장바구니에 담습니다.
  - 일반결제 : ‘신용카드, 실시간 계좌이체, 가상계좌, 휴대폰 소액결제, 상품권’을 의미합니다.
  - 간편결제 : 인증이 간소화된 결제방식입니다.
  - 해외결제 : 해외카드를 포함한 해외지역 결제입니다.
  - 본인인증 : 본인임을 확인하는 인증 서비스입니다.
- 연동방식 : 결제대행사별로 지원 가능한 결제수단과 연동방식에 차이가 있으므로 원하시는 서비스가 해당 결제대행사에서 지원되는지 확인해 주세요.
- 선택한 결제 서비스 확인 > 전자결제 신청 : 노출되어 있는 결제대행사 카드는 모두 접수 처리되오니 최종 접수 이전에 이용하실 결제대행사를 한 번 더 체크해 주세요.

#### **추가 작성 항목**



결제대행사와 결제수단을 다시 선택하고자 하실 경우 \[다시 선택할게요]를 클릭해 주세요

- 네이버페이(주문형/결제형) 개발방식
  - 자체개발 : 연동하실 사이트를 직접 개발하여 연동하시는 경우
  - 워드프레스 : 워드프레스로 사이트를 구축하신 경우
- 카카오페이 배송 및 서비스 기간 : 고객에게 서비스가 제공되기까지의 기간을 적어주세요.
  - 실물(배송되는) 상품이라면: 배송 기간
  - 비실물(컨텐츠) 상품이라면: 서비스를 이용할 수 있는 기간
- 나이스페이먼츠 정산 계좌정보  : 나이스페이로부터 결제대금을 정산받으실사업자의 정산계좌를 적어주세요.  (나이스페이먼츠 접수시스템상 미리 적게 되어있으며, 그 외 PG사의 경우 추후 계약서 작성시 기입하게
  되어있습니다)



결제대행사와 결제수단을 다시 선택하고자 하실 경우 \[다시 선택할게요]를 클릭해 주세요

- KG이니시스 홈페이지 명(서비스명)
  - 사업자에서 운영하실 서비스의 이름을 적어주세요.
- 페이먼트월 결제 제공 국가
  - 결제서비스를 제공할 구매자의 국가를 골라주세요. 검색란 클릭 시 국가 리스트가 확인됩니다.
- 페이코
  - 페이코 ID : 페이코 어드민 페이지에서 로그인할 수 있는 이메일 주소를 입력해 주세요.
  - 은행명 : 페이코로부터 정산 받으실 사업장 계좌의 은행명을 적어주세요.
  - 계좌번호 : 페이코로부터 정산 받으실 사업장 계좌의 계좌번호를 적어주세요.
  - 예금주 : 페이코로부터 정산 받으실 사업장 계좌의 예금주를 적어주세요.
